from flask import flash, redirect, url_for


def error_obj_not_found(obj_cls, blueprint):
    flash(f"{obj_cls.__name__} not found", "warning")
    return redirect(url_for(f"{blueprint}.{obj_cls.__name__.lower()}_index"))



from .base import Auxs  # noqa F401
from .errors import error_obj_not_found  # noqa F401
from .exceptions import NotAllowed, PermissionDenied  # noqa F401
from .url_helpers import get_cancel, get_next, valid_url  # noqa F401



from urllib.parse import urlparse

from flask import abort, request


def valid_url(url):
    if urlparse(url).netloc != "":
        return False

    return True


def get_url(arg):
    url = request.args.get(arg, "/")
    if not valid_url(url):
        abort(403)
    else:
        return url


def get_next():
    return get_url(arg="next")


def get_cancel():
    return get_url(arg="cancel")



from zoneinfo import ZoneInfo

from flask import request


class Auxs:
    def __init__(self, app=None):
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        @app.context_processor
        def inject_redir_path():
            query_string = request.query_string.decode()
            redir_path = (
                request.path if not query_string else request.path + "?" + query_string
            )

            return dict(redir_path=redir_path)

        @app.template_filter()
        def dtformat(dt):
            utc_dt = dt.replace(tzinfo=ZoneInfo("UTC"))
            local_dt = utc_dt.astimezone(ZoneInfo(app.config.get("TIME_ZONE")))

            format = "%d %b %Y, %H:%M"

            return local_dt.strftime(format)
